@@ -660,14 +660,13 @@ def sbng(bng, md=5, crt=None, skip_mos=['m', 'o', 'sv'], met_dist='manh', met='c
             for j in range(len(ix)): bins[j + 1] = bns[ix.flatten()[j]]
             bns = bins
             xtp1 = 'ord'
-
         if met == 'hclust':
             bns, map, D = spih_sb_hclust(bns, xtp1, md, met_dist)
         elif met == 'co1y':
             bd = nmin_uy[0]
-            gd = nmin_uy[1] 
+            gd = nmin_uy[1]
             nd = nmin_uy[2]
-            bns, map, D = spih_sb_co1y(bns, crt, xtp1, ytp, md, gd, bd, nd, mar, pt, ba, dGBInd, tolmindGBInd, mt, minB, tolminB, maxprm, dsp)
+            bns, map, D = spih_sb_co1y(bns, crt, xtp1, ytp, md, gd, bd, nd, mar, pt, ba, dGBInd, tolmindGBInd, mt, minB, tolminB, maxprm, dsp, cname)
         flg = 0
         if bns is None:
             bns = bng[i]['bns']
@@ -927,7 +926,7 @@ def spih_erv(x, w, xtp, md, sv):
 
 
 ###################################################################################
-def spih_sb_co1y(bns, crt, xtp, ytp, md, gd, bd, nd, mar, pt, ba, dGBInd, tolmindGBInd, mt, minB, tolminB, maxprm, dsp):
+def spih_sb_co1y(bns, crt, xtp, ytp, md, gd, bd, nd, mar, pt, ba, dGBInd, tolmindGBInd, mt, minB, tolminB, maxprm, dsp, cname=''):
     if crt is None:
         if ytp[0] == 'bin':     crt = 'chi2'
         elif ytp[0] == 'num':   crt = 'frat'
@@ -1009,7 +1008,7 @@ def spih_sb_co1y(bns, crt, xtp, ytp, md, gd, bd, nd, mar, pt, ba, dGBInd, tolmin
                 pvalc_b[br] = np.nan
                 bns_b[br] = None
                             
-            if dsp: print('Run SB: ', i + 1, '/', m, cname, ',      time: ', toc5(dsp=False))
+            if dsp: print('Run SB: ', br + 1, '/', m, cname, ',      time: ', toc5(dsp=False))
 
         else:
             crit_b[br] = np.nan
@@ -1046,8 +1045,6 @@ def spih_sb_co1y(bns, crt, xtp, ytp, md, gd, bd, nd, mar, pt, ba, dGBInd, tolmin
                     if np.any(m_(bns[i]['lb']) == m_(bns_b[j]['lb'])):
                         map[i-1, :] = [i, j]
                         continue
-    else:
-        map = []
 
     return bns_b, map.astype(int), crit_b
 
