@@ -7,7 +7,9 @@ Matlab version:
     course: Multivariable Control Systems
 """
 import numpy as np
-from aislab.md_reg import *# needed for vif()
+from numpy.matlib import repmat # needed for vif()
+
+from aislab.md_reg import *     # needed for vif()
 from aislab.gnrl.bf import *
 
 
@@ -410,7 +412,7 @@ def pvalF(F, v1, v2, tp='ot'):
     p[p > 1] = 1  #
     return p
 ###################################################################################
-def vaf(Y, Ym, w=np.empty([0, 0]), p=0, floor_to_0=True):
+def vaf(Y, Ym, w=np.empty([0, 0]), p=1, floor_to_0=True):
     Nw, r = Y.shape
     if w.size > 0:
         if w.size < Y.size: w = np.tile(w, (1, r))
@@ -428,17 +430,57 @@ def vaf(Y, Ym, w=np.empty([0, 0]), p=0, floor_to_0=True):
 ###################################################################################
 def vif(x):
     m = x.shape[1]
-    vifi = nans((m, 1))
+    vifi = nans(m, 1)
     for i in range(m):
         yi = c_(x[:, i])
         xi = np.delete(x, i, axis=1)
-        mdl = lspm(xi, yi)
-        yim = lspm_apl(xi, yi, mdl=mdl)
-        R2 = vaf(yi, yim)/100
-        if R2 == 1:
+        pm = lspm(F=xi, Y=yi)
+        yim = lin_apl(xi, pm)
+        r2 = vaf(yi, yim)/100
+        if r2 == 1:
             vifi[i] = np.inf
         else:
-            vifi[i] = 1/(1 - R2)
+            vifi[i] = 1 / (1 - r2)
+    return vifi
+###################################################################################
+def vif1(x, w=None, s_min=1e-12):
+    m = x.shape[1]
+    N, z = x.shape
+    if w is None: w = ones(N, 1)
+    Nw = sum(w)[0]
+    FF = x.T @ (w * x)
+    my = x.T @ w / Nw
+    SST = np.sum((x - repmat(r_(my), N, 1)) ** 2, axis=0)
+    SSY = np.sum(x ** 2 * w, axis=0)
+
+    vifi = nans(m, 1)
+    ivi0 = np.arange(m)
+    for i in range(m):
+        # yi = c_(x[:, i])
+        # xi = np.delete(x, i, axis=1)
+        # pm = lspm(F=xi, Y=yi)
+        # yim = lin_apl(xi, pm)
+        # r2 = vaf(yi, yim)/100
+
+        ivi = ivi0[np.hstack((np.arange(0, i), np.arange(i + 1, m)))]
+        FFi = sm_(FF, ivi, ivi)
+        Fy = c_(FF[i, ivi])
+        if FFi.size == 1:
+            P = 1 / FFi
+        else:
+            rcM = 1 / np.linalg.cond(FFi)  # todo: make function in sf, calculating condition number
+            if rcM < 1e-3:
+                P = nsinv(FFi, s_min)
+            else:
+                P = np.linalg.inv(FFi)
+        sse = np.max([0, SSY[i] - Fy.T @ P @ Fy])
+        r2 = np.max([0, 1 - sse / SST[i]])
+
+        if r2 == 1:
+            vifi[i] = np.inf
+        else:
+            vifi[i] = 1 / (1 - r2)
+        # print(r2 - R2)
     return vifi
 ###################################################################################
 def vinf(g, b, tau=1e-12):
