@@ -10,8 +10,8 @@ import pandas as pd
 import copy
 import warnings as wn
 
-from gnrl.sf import *
-from gnrl.measr import *
+from aislab.gnrl.sf import *
+from aislab.gnrl.measr import *
 
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 500)
