@@ -1,9 +1,9 @@
 import numpy as np
 import pandas as pd
-from op_nlopt.ord12 import *
-from op_nlopt.cstm import *
-from gnrl.sf import *
-from gnrl.measr import *
+from aislab.op_nlopt.ord12 import *
+from aislab.op_nlopt.cstm import *
+from aislab.gnrl.sf import *
+from aislab.gnrl.measr import *
 
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 500)
