@@ -384,7 +384,9 @@ def lspm(U=m_(), Y=m_(), E=m_(), Farx=m_(), F=m_(), W=m_(), na=0, nb=0, nc=0, pm
     """
 
     N, r = Y.shape
-    m = U.shape[1]
+    if len(U) > 0:  m = U.shape[1]
+    elif len(F) > 0:  m = F.shape[1]
+    else: raise Exception("In LSPM: Independent variables (U or F matrix) are not specified.")
     n = max(na, nb, nc)
     if len(F) == 0 and n > 0:       # dynamic model
         F = dmpm(U, Y, E, na=na, nb=nb, nc=nc, pm0=pm0, ivi=ivi)
