@@ -23,12 +23,9 @@ def rls(U, Y, pm, P,
         nb=None,
         pm0=None,
         mod=None,
-        Ne=None,
         se=None,
         rvmin=None,
         rv=None,
-        mee=None,
-        ee=None,
         a=None,
         rc=None,
         trPmin=None,
@@ -48,8 +45,6 @@ def rls(U, Y, pm, P,
     if (np.array([pm0 == None])).any():
         if 'pm0' in par:    pm0 = par['pm0']
         else:               pm0 = np.zeros((r, 1))
-    if Ne == None and 'Ne' in par:         Ne = par['Ne']
-    else:                                  Ne = 'non'
     if mod == None and 'mod' in par:       mod = par['mod']
     else:                                  mod = 'non'
     if (np.array([se == None])).any() and 'se' in par:          se = par['se']
@@ -58,17 +53,6 @@ def rls(U, Y, pm, P,
         if 'rv' in par:                    rv = par['rv']
         else:                              rv = np.ones([r])
     
-    if mee == None and 'mee' in par:       mee = par['mee'] # else: mee=np.empty(())
-    if ee == None and 'ee' in par:         ee = par['ee']   # else: ee=np.zeros([r])
-    
-    if (np.array([mee == None])).any():
-        if 'mee' in par:    mee = par['mee']
-        else:               mee = np.empty(())
-    if (np.array([ee == None])).any():
-        if 'ee' in par:     ee = par['ee']
-        else:               ee = np.zeros((r))
-    
-    
     if a == None and 'a' in par:           a = par['a']
     if rc == None and 'rc' in par:         rc = par['rc']
     if trPmin == None and 'rePmin' in par: trPmin = par['trPmin']
@@ -81,13 +65,12 @@ def rls(U, Y, pm, P,
     if type(se) != np.ndarray:      se = np.array([se])
     if type(rvmin) != np.ndarray:   rvmin = np.array([rvmin])
     if type(rv) != np.ndarray:      rv = np.array([rv])
-    if type(mee) != np.ndarray:     mee = np.array([mee])
-    if type(ee) != np.ndarray:      ee = np.array([ee])
 
     yk = c_(Y[-1, :])
     fi = dmpv(U, Y, na=na, nb=nb, pm0=pm0).T
     pm = c_(pm)
-    
+    nn = np.sum(np.hstack((na, nb, pm0)), axis=1).astype(int)
+
     # residual update
     e = yk - fi.T@pm
     # Kalman gain (K) & Covariance matrix (P) update
@@ -124,7 +107,6 @@ def rls(U, Y, pm, P,
 #        K = P*fi@np.linalg.inv(rc*np.eye(r) + fi.T@P@fi)
 #        P = rc ^ -1@(P - K@fi.T@P)
         
-        nn = np.sum(np.hstack((na, nb, pm0)), axis=1).astype(int)
         c = np.sqrt(rc)
         C = np.zeros((int(np.sum(nn))))
         for i in range(r):
@@ -138,22 +120,7 @@ def rls(U, Y, pm, P,
         else:          K = P@C1@fi@np.linalg.inv(M)
         P = C1@(P - K@fi.T@C1@P)@C1 # (A + B*C*D)^?1 = A^?1 ? A^?1*B(C^?1 + D*A^?1*B)^?1*D*A^?1
     elif mod == 'vff':
-        nn = np.sum(np.hstack((na, nb, pm0)), axis=1)
-
-        le = ee.shape[1]
-        if le > 0: me = mee[:, 0:0 + 1]
-        else:      me = np.zeros((r, 1))
-
-        if le > Ne:
-            me = me + (e - ee[:, le - 1])/Ne
-            se = se + ((e - me)**2 - (ee[:, le - 1] - mee[:, len(mee) - 1])**2)/(Ne - 1)
-        elif le > 1:
-            me = me + e/le
-            se = se + 1/(le - 1)*(e - me)**2
-        elif le == 1:
-            me = e
-        # else --> le == 0  => me = 0
-
+        # se = (se*np.max([1, k - nn - 2])*1 + e**2)/np.max([1, k - nn - 1])
         nn = np.sum(np.hstack((na, nb, pm0)), axis=1).astype(int)
         c = np.sqrt(rv)
         C = np.zeros((int(np.sum(nn))))
@@ -169,22 +136,10 @@ def rls(U, Y, pm, P,
         else:          K = P@C1@fi@np.linalg.inv(M)
         P = C1@(P - K@fi.T@C1@P)@C1
 
-        if mee.size == 0: mee = np.empty((len(me), 0))
-        if ee.size == 0:  ee = np.empty((len(e), 0))
-
-        if mee.shape[1] < Ne:
-            mee = np.hstack((mee, me))
-            ee = np.hstack((ee, e))
-        else:
-            mee = np.hstack((ee[:, 1:Ne], me))
-            ee = np.hstack((ee[:, 1:Ne], e))
-
         # rv = np.max(np.hstack((1 - (1 - fi.T@K)@(e**2)/(se*Ne), rvmin.reshape(-1, 1))), axis=1)
-        rv = np.max(np.hstack((1 - (1 - fi.T@K)@(e**2)/(se), rvmin.reshape(-1, 1))), axis=1)
+        rv = np.max(np.hstack((1 - (1 - fi.T@K)@e**2/se, rvmin.reshape(-1, 1))), axis=1)
         par['rv'] = rv
-        par['mee'] = mee
         par['se'] = se
-        par['ee'] = ee
 
     # model parameters (pm) update
     pm = pm + K@e
