@@ -9,7 +9,7 @@ from numpy import matlib
 
 from aislab.md_reg.linest import *
 from aislab.md_fsel.swlinr import *
-from aislab.gnrl.bf import *# c_
+from aislab.gnrl.bf import * # c_
 from aislab.gnrl.sf import *
 from aislab.gnrl.measr import*
 
@@ -27,6 +27,10 @@ def arx(U, Y, W=None, na=None, nb=None, pm0=None, cnames=None, rtp='PV', mxtp='d
     N, r = Y.shape
     m = U.shape[1]
 
+    if r == 1 and rtp == 'PV':
+        rtp = 'PM'
+        wn.warn('In ARX(): The PV representation ischanged to PM form, as the model has one output.')
+
     # Check na and nb
     na = chkn(n=na, size=(r, r), rtp=rtp, name='na', fname='ARX()')
     nb = chkn(n=nb, size=(r, m), rtp=rtp, name='nb', fname='ARX()')
@@ -48,8 +52,26 @@ def arx(U, Y, W=None, na=None, nb=None, pm0=None, cnames=None, rtp='PV', mxtp='d
     if fsel is None:
         mdl = ts(U, Y, W=W, na=na, nb=nb, pm0=pm0, ivi=ivi, cnames=cnames.flatten(), mtp=mtp, rtp=rtp, smr=smr, s_min=s_min)
     elif fsel == 'SWR':
-        mdl = swlinr(U=U, Y=Y, W=W, na=na, nb=nb, pm0=pm0, cnames=cnames, mtp=mtp, rtp=rtp, met=fsel, SLE=SLE, SLS=SLS, crit_nbm=crit_nbm, mdl_init=mdl_init, ivi=ivi, val_prc=val_prc, s_min=s_min, dsp=fsel_dsp)
-        
+        if rtp == 'PM':
+            mdl = swlinr(U=U, Y=Y, W=W, na=na, nb=nb, pm0=pm0, cnames=cnames, mtp=mtp, met=fsel, SLE=SLE, SLS=SLS, crit_nbm=crit_nbm, mdl_init=mdl_init, ivi=ivi, val_prc=val_prc, s_min=s_min, dsp=fsel_dsp)
+        elif rtp == 'PV' and r > 1:
+            n = np.max(np.hstack((na, nb)))
+
+            W0 = W
+
+            W = W[n:, :]
+            F = dmpm(U, Y, na=na, nb=nb, pm0=pm0) # intercept is added in swlinr()
+            mdl_i = [None]*r
+
+            mdlPM = swlinr(U=U, Y=Y, W=W0, na=na[0,0], nb=nb[0,0], pm0=pm0[0,0], cnames=c_(cnames[:22]), mtp=mtp, met=fsel, SLE=SLE, SLS=SLS, crit_nbm=crit_nbm, mdl_init=mdl_init, ivi=ivi[0], val_prc=val_prc, s_min=s_min, dsp=fsel_dsp)
+
+            
+            for i in np.arange(r):
+                z = np.sum(na[i, :]) + np.sum(nb[i, :]) + pm0[i,0]
+                cnames_i = cnames[i*z:(i + 1)*z]
+                Yi = c_(Y[n:, i])
+                mdl_i[i] = swlinr(F=F, Y=Yi, W=W, m=m, r=1, na=na[i, :], nb=nb[i, :], pm0=pm0[i], cnames=cnames_i, mtp=mtp, met=fsel, SLE=SLE, SLS=SLS, crit_nbm=crit_nbm, mdl_init=mdl_init, ivi=ivi[i], val_prc=val_prc, s_min=s_min, dsp=fsel_dsp)
+            mdl = mrgswr(mdl_i)
     return mdl
 
 def armax(U, Y, W=None, na=None, nb=None, nc=None, pm0=None, rtp='PV', smr=True):
@@ -252,6 +274,18 @@ def chkw(X, N=None, fname=None):
         raise Exception('In ' + fname + ': Weight factor must not be empty matrix.')
     return X
 
+##############################################################################
+def mrgswr(mdls):
+    r = len(mdls)
+    ms = np.max([len(mdls[i]) for i in np.arange(r)])  # max steps
+    mdl = mdls[0]
+    i = 1
+    for mdl_i in mdls[1:]:
+        mdl[i]
+        i += 1
+    return mdl
+# merge models in PV form produced by swlinr()
+
 ##############################################################################
 def names(name='var_', z=1, na=None, nb=None, nc=None, pm0=None, r=None, m=None, rtp=None):
     # z - number of factors
