@@ -3,7 +3,7 @@ import pandas as pd
 
 from aislab.gnrl.sf import *
 from aislab.gnrl.measr import *
-from aislab.tests.cstm_ga_scoring import *
+# from aislab.tests.cstm_ga_scoring import *
 
 ##############################################################################
 
@@ -21,7 +21,7 @@ def fobj_sim(max_F, itrConstF):
     return result
 
 ##############################################################################
-def genopt(fobj, args, n=1, lb=0, ub=1, tpg='float', mod_indv='single', Nind=100, mut_rate=50, mut_strength=2, mut_met='Gauss', mut_stdev=70, pairing_met='Fbest', select_met='Fhalf', itrConstF=10, maxiter=100):
+def genopt(fobj, args, n=1, lb=0, ub=1, tpg='float', mod_indv='single', Nind=100, mut_rate=50, mut_strength=2, mut_met='Gauss', mut_stdev=70, pairing_met='Fbest', select_met='Fhalf', itrConstF=10, maxiter=100, dsp=False):
     # first generation
     indvs = population(Nind, n, lb, ub, tpg, mod_indv, 0)
     F = fobj(indvs, args)
@@ -47,7 +47,7 @@ def genopt(fobj, args, n=1, lb=0, ub=1, tpg='float', mod_indv='single', Nind=100
         F, ind = sort(F)
         indvs = indvs[ind]
         FF = np.append(FF, F[0])
-        print(itr, 'Fmin = ', F[0])
+        if dsp: print(itr, 'Fmin = ', F[0])
         iterate = stopcrt_ga(FF, itr, itrConstF, maxiter)
     x_opt = np.array(indvs[0])
     F_opt = F[0]
