@@ -69,18 +69,18 @@ def newton(x, func, grad, hes, args, met_opt='newt', maxiter=50, fcnv=None, afcn
             iterate = 0
             msg = 'H'
             continue
-        iterate, msg = stopcrt(x, F, xx, FF, g, H, itr, maxiter, fcnv, afcnv, xcnv, gcnv, sc)
+        # Hessian Inverse
+        if not len(Hinv)==0: Hinv_1 = Hinv
+        rcH = 1/np.linalg.cond(H)
+        if rcH < rcondH: Hinv = nsinv(H)
+        else:          Hinv = np.linalg.inv(H)
+        iterate, msg = stopcrt(x, F, xx, FF, g, H, Hinv, itr, maxiter, fcnv, afcnv, xcnv, gcnv, sc)
         if itr > 0 and iterate: x, F, g, H, Hinv, tmp, sc, iterate, msg, flg_omit = optOmit(x, xx, F, FF, g, g_1, H, H_1, Hinv, Hinv_1, iterate, s, tmp, sc, smeth, dsp_op)
         if iterate == 0:
             if itr > 1 and F > FF[0]: F = FF[0]; x = c_(xx[:, 0]); g = g_1; H = H_1; Hinv = Hinv_1
         # dspl_logr(flg, x, F, itr, args.cnames, par)
         if dsp_op == 2: dspl(flg=dsp_op, x=x, F=F, itr=itr, args=args, s=s, meth=met_opt)
         if iterate == 0: continue
-        # Hessian Inverse
-        if not len(Hinv)==0: Hinv_1 = Hinv
-        rcH = 1/np.linalg.cond(H)
-        if rcH < rcondH: Hinv = nsinv(H)
-        else:          Hinv = np.linalg.inv(H)
         # Descent Direction (p) & Quadratic Approx Step Size (p_len)
         p = -Hinv@g
         p_len = max([1e-12, np.sqrt(p.T@p)[0, 0]])
@@ -114,6 +114,6 @@ def newton(x, func, grad, hes, args, met_opt='newt', maxiter=50, fcnv=None, afcn
         rcH = 1/np.linalg.cond(H)
         if rcH < 1e-6: Hinv = nsinv(H)
         else:          Hinv = np.linalg.inv(H)
-    if dsp_op: dspl(flg=1, x=x, xx=xx, F=F, FF=FF, g=g, H=H, itr=itr, msg=msg, maxiter=maxiter, fcnv=fcnv, afcnv=afcnv, xcnv=xcnv, gcnv=gcnv)
+    if dsp_op: dspl(flg=1, x=x, xx=xx, F=F, FF=FF, g=g, H=H, Hinv=Hinv, itr=itr, msg=msg, maxiter=maxiter, fcnv=fcnv, afcnv=afcnv, xcnv=xcnv, gcnv=gcnv)
     return x, F, g, H, Hinv, itr
 
